@@ -25,7 +25,7 @@ use crate::node::{
         core::{
             ConnectionEvent, Core, Proposal, RESOURCE_PROOF_DATA_SIZE, RESOURCE_PROOF_DIFFICULTY,
         },
-        create_test_used_space_and_root_storage,
+        create_test_max_capacity_and_root_storage,
         dkg::test_utils::{prove, section_signed},
         ed25519,
         messages::{NodeMsgAuthorityUtils, WireMsgUtils},
@@ -77,14 +77,14 @@ async fn receive_join_request_without_resource_proof_response() -> Result<()> {
 
     let (section, section_key_share) = create_section(&sk_set, &section_auth).await?;
     let node = nodes.remove(0);
-    let (used_space, root_storage_dir) = create_test_used_space_and_root_storage()?;
+    let (max_capacity, root_storage_dir) = create_test_max_capacity_and_root_storage()?;
     let core = Core::new(
         create_comm().await?,
         node,
         section,
         Some(section_key_share),
         mpsc::channel(TEST_EVENT_CHANNEL_SIZE).0,
-        used_space,
+        UsedSpace::new(max_capacity),
         root_storage_dir,
         false,
     )
@@ -158,14 +158,14 @@ async fn receive_join_request_with_resource_proof_response() -> Result<()> {
 
     let (section, section_key_share) = create_section(&sk_set, &section_auth).await?;
     let node = nodes.remove(0);
-    let (used_space, root_storage_dir) = create_test_used_space_and_root_storage()?;
+    let (max_capacity, root_storage_dir) = create_test_max_capacity_and_root_storage()?;
     let core = Core::new(
         create_comm().await?,
         node,
         section,
         Some(section_key_share),
         mpsc::channel(TEST_EVENT_CHANNEL_SIZE).0,
-        used_space,
+        UsedSpace::new(max_capacity),
         root_storage_dir,
         false,
     )
@@ -256,14 +256,14 @@ async fn receive_join_request_from_relocated_node() -> Result<()> {
     let (section, section_key_share) = create_section(&sk_set, &section_auth).await?;
     let node = nodes.remove(0);
     let node_name = node.name();
-    let (used_space, root_storage_dir) = create_test_used_space_and_root_storage()?;
+    let (max_capacity, root_storage_dir) = create_test_max_capacity_and_root_storage()?;
     let core = Core::new(
         create_comm().await?,
         node,
         section,
         Some(section_key_share),
         mpsc::channel(TEST_EVENT_CHANNEL_SIZE).0,
-        used_space,
+        UsedSpace::new(max_capacity),
         root_storage_dir,
         false,
     )
@@ -357,14 +357,14 @@ async fn handle_agreement_on_online() -> Result<()> {
     let (section_auth, mut nodes, sk_set) = gen_section_authority_provider(prefix, elder_count());
     let (section, section_key_share) = create_section(&sk_set, &section_auth).await?;
     let node = nodes.remove(0);
-    let (used_space, root_storage_dir) = create_test_used_space_and_root_storage()?;
+    let (max_capacity, root_storage_dir) = create_test_max_capacity_and_root_storage()?;
     let core = Core::new(
         create_comm().await?,
         node,
         section,
         Some(section_key_share),
         event_tx,
-        used_space,
+        UsedSpace::new(max_capacity),
         root_storage_dir,
         false,
     )
@@ -420,14 +420,14 @@ async fn handle_agreement_on_online_of_elder_candidate() -> Result<()> {
     let node = nodes.remove(0);
     let node_name = node.name();
     let section_key_share = create_section_key_share(&sk_set, 0);
-    let (used_space, root_storage_dir) = create_test_used_space_and_root_storage()?;
+    let (max_capacity, root_storage_dir) = create_test_max_capacity_and_root_storage()?;
     let core = Core::new(
         create_comm().await?,
         node,
         section,
         Some(section_key_share),
         mpsc::channel(TEST_EVENT_CHANNEL_SIZE).0,
-        used_space,
+        UsedSpace::new(max_capacity),
         root_storage_dir,
         false,
     )
@@ -591,14 +591,14 @@ async fn handle_agreement_on_online_of_rejoined_node(phase: NetworkPhase, age: u
     // Make a Node
     let (event_tx, _) = mpsc::channel(TEST_EVENT_CHANNEL_SIZE);
     let node = nodes.remove(0);
-    let (used_space, root_storage_dir) = create_test_used_space_and_root_storage()?;
+    let (max_capacity, root_storage_dir) = create_test_max_capacity_and_root_storage()?;
     let state = Core::new(
         create_comm().await?,
         node,
         section,
         Some(section_key_share),
         event_tx,
-        used_space,
+        UsedSpace::new(max_capacity),
         root_storage_dir,
         false,
     )
@@ -661,14 +661,14 @@ async fn handle_agreement_on_offline_of_non_elder() -> Result<()> {
 
     let (event_tx, _event_rx) = mpsc::channel(TEST_EVENT_CHANNEL_SIZE);
     let node = nodes.remove(0);
-    let (used_space, root_storage_dir) = create_test_used_space_and_root_storage()?;
+    let (max_capacity, root_storage_dir) = create_test_max_capacity_and_root_storage()?;
     let core = Core::new(
         create_comm().await?,
         node,
         section,
         Some(section_key_share),
         event_tx,
-        used_space,
+        UsedSpace::new(max_capacity),
         root_storage_dir,
         false,
     )
@@ -716,7 +716,7 @@ async fn handle_agreement_on_offline_of_elder() -> Result<()> {
 
     // Create our node
     let (event_tx, _event_rx) = mpsc::channel(TEST_EVENT_CHANNEL_SIZE);
-    let (used_space, root_storage_dir) = create_test_used_space_and_root_storage()?;
+    let (max_capacity, root_storage_dir) = create_test_max_capacity_and_root_storage()?;
     let node = nodes.remove(0);
     let node_name = node.name();
     let core = Core::new(
@@ -725,7 +725,7 @@ async fn handle_agreement_on_offline_of_elder() -> Result<()> {
         section,
         Some(section_key_share),
         event_tx,
-        used_space,
+        UsedSpace::new(max_capacity),
         root_storage_dir,
         false,
     )
@@ -829,14 +829,14 @@ async fn ae_msg_from_the_future_is_handled() -> Result<()> {
     let (event_tx, mut event_rx) = mpsc::channel(TEST_EVENT_CHANNEL_SIZE);
     let section_key_share = create_section_key_share(&sk_set1, 0);
     let node = nodes.remove(0);
-    let (used_space, root_storage_dir) = create_test_used_space_and_root_storage()?;
+    let (max_capacity, root_storage_dir) = create_test_max_capacity_and_root_storage()?;
     let core = Core::new(
         create_comm().await?,
         node,
         network_knowledge,
         Some(section_key_share),
         event_tx,
-        used_space,
+        UsedSpace::new(max_capacity),
         root_storage_dir,
         false,
     )
@@ -942,14 +942,14 @@ async fn untrusted_ae_message_msg_errors() -> Result<()> {
 
     let (event_tx, _) = mpsc::channel(TEST_EVENT_CHANNEL_SIZE);
     let node = create_node(MIN_ADULT_AGE, None);
-    let (used_space, root_storage_dir) = create_test_used_space_and_root_storage()?;
+    let (max_capacity, root_storage_dir) = create_test_max_capacity_and_root_storage()?;
     let core = Core::new(
         create_comm().await?,
         node,
         our_section.clone(),
         None,
         event_tx,
-        used_space,
+        UsedSpace::new(max_capacity),
         root_storage_dir,
         false,
     )
@@ -1050,14 +1050,14 @@ async fn relocation(relocated_peer_role: RelocatedPeerRole) -> Result<()> {
     let node_state = section_signed(sk_set.secret_key(), node_state)?;
     assert!(section.update_member(node_state).await);
     let node = nodes.remove(0);
-    let (used_space, root_storage_dir) = create_test_used_space_and_root_storage()?;
+    let (max_capacity, root_storage_dir) = create_test_max_capacity_and_root_storage()?;
     let core = Core::new(
         create_comm().await?,
         node,
         section,
         Some(section_key_share),
         mpsc::channel(TEST_EVENT_CHANNEL_SIZE).0,
-        used_space,
+        UsedSpace::new(max_capacity),
         root_storage_dir,
         false,
     )
@@ -1152,14 +1152,14 @@ async fn message_to_self(dst: MessageDst) -> Result<()> {
     let (event_tx, _) = mpsc::channel(TEST_EVENT_CHANNEL_SIZE);
     let (comm_tx, mut comm_rx) = mpsc::channel(TEST_EVENT_CHANNEL_SIZE);
     let comm = Comm::new((Ipv4Addr::LOCALHOST, 0).into(), Default::default(), comm_tx).await?;
-    let (used_space, root_storage_dir) = create_test_used_space_and_root_storage()?;
+    let (max_capacity, root_storage_dir) = create_test_max_capacity_and_root_storage()?;
 
     let genesis_sk_set = bls::SecretKeySet::random(0, &mut rand::thread_rng());
     let core = Core::first_node(
         comm,
         node,
         event_tx,
-        used_space,
+        UsedSpace::new(max_capacity),
         root_storage_dir,
         genesis_sk_set,
     )
@@ -1268,14 +1268,14 @@ async fn handle_elders_update() -> Result<()> {
     };
 
     let (event_tx, mut event_rx) = mpsc::channel(TEST_EVENT_CHANNEL_SIZE);
-    let (used_space, root_storage_dir) = create_test_used_space_and_root_storage()?;
+    let (max_capacity, root_storage_dir) = create_test_max_capacity_and_root_storage()?;
     let core = Core::new(
         create_comm().await?,
         node,
         section0.clone(),
         Some(section_key_share),
         event_tx,
-        used_space,
+        UsedSpace::new(max_capacity),
         root_storage_dir,
         false,
     )
@@ -1388,14 +1388,14 @@ async fn handle_demote_during_split() -> Result<()> {
     }
 
     let (event_tx, _) = mpsc::channel(TEST_EVENT_CHANNEL_SIZE);
-    let (used_space, root_storage_dir) = create_test_used_space_and_root_storage()?;
+    let (max_capacity, root_storage_dir) = create_test_max_capacity_and_root_storage()?;
     let core = Core::new(
         create_comm().await?,
         node,
         section,
         Some(section_key_share),
         event_tx,
-        used_space,
+        UsedSpace::new(max_capacity),
         root_storage_dir,
         false,
     )
