@@ -130,7 +130,8 @@ impl Comm {
             wire_msg.set_dst_xorname(name);
 
             let bytes = wire_msg.serialize()?;
-            let priority = wire_msg.msg_kind().priority();
+            // TODO: rework priority so this we dont need to deserialise payload to determine priority.
+            let priority = wire_msg.into_message()?.priority();
             let retries = self.back_pressure.get(&addr).await; // TODO: more laid back retries with lower priority, more aggressive with higher
 
             let connection = if let Some(connection) = recipient.connection().await {
@@ -232,7 +233,7 @@ impl Comm {
         }
 
         let msg_bytes = wire_msg.serialize().map_err(Error::Messaging)?;
-        let priority = wire_msg.msg_kind().priority();
+        let priority = wire_msg.clone().into_message()?.priority();
 
         // Run all the sends concurrently (using `FuturesUnordered`). If any of them fails, pick
         // the next recipient and try to send to them. Proceed until the needed number of sends
